@@ -1,4 +1,5 @@
 from __future__ import annotations
+from dataclasses import dataclass
 from inspect import signature
 from asyncio.tasks import Task, ensure_future
 from io import BytesIO
@@ -52,35 +53,22 @@ class Event:
             if not i[1] or (i[1] and i[1](data)):
                 self.futures.append(asyncio.ensure_future(i[0](data)))
                 if self.futures.__len__() > self.workers:
-                    await asyncio.gather(*self.futures)
+                    for i in self.futures:
+                        if i.done():
+                            self.futures.remove(i)
+                    if self.futures.__len__() > self.workers:
+                        await asyncio.gather(*self.futures)
 
 
+@dataclass
 class Attachment:
-    """
-    :param mail: mail
-    :param mail_id: Mail Identity
-    :param attachment_id: Attachment Identity
-    :param content_id: str
-    :param name: filename
-    :param size: Filesize
-    """
-    def __init__(
-            self,
-            mail,
-            mail_id: int,
-            attachment_id: int,
-            content_id: str,
-            name: str,
-            size: int,
-            myemail: Email
-    ) -> None:
-        self.mail = mail
-        self.mail_id = mail_id
-        self.id = attachment_id
-        self.content_id = content_id
-        self.name = name
-        self.size = size
-        self.myemail = myemail
+    mail: str
+    mail_id: int
+    attachment_id: int
+    content_id: str
+    name: str
+    size: int
+    myemail: Email
 
     async def download(self) -> BytesIO:
         """
@@ -103,14 +91,10 @@ class Attachment:
         return f'<["{self.name}" size:{self.size}]>'
 
 
+@dataclass
 class StrangerMail:
-    """
-        :param account: Email
-        :param stranger: str
-    """
-    def __init__(self, account: Email, stranger: str) -> None:
-        self.email = stranger
-        self.account = account
+    account: Email
+    email: str
 
     async def send_message(
             self,
@@ -232,8 +216,7 @@ class Email(httpx.AsyncClient):
         while True:
             futures.append(ensure_future(
                 asyncio.gather(*[
-                    ensure_future(
-                        self.on.on_message(i)) for i in (
+                        self.on.on_message(i) for i in (
                             await self.get_new_message())])))
             await asyncio.sleep(interval)
             for i in futures:
@@ -330,7 +313,7 @@ class Email(httpx.AsyncClient):
                 }, files=tuple(files))).json()['result']
 
     async def secret_address(self) -> Email:
-        if self.protected:
+        if await self.protected():
             raise InvalidPIN()
         em, ex = (await self.get(
             'https://tempmail.plus/api/box/hidden'
@@ -346,7 +329,7 @@ class Email(httpx.AsyncClient):
         return False
 
     async def Lock_Inbox(self, pin: str, duration_minutes: int = 60) -> bool:
-        if self.protected:
+        if await self.protected():
             raise InvalidPIN()
         cp_params = self.params.copy()
         cp_params.update({
@@ -362,7 +345,7 @@ class Email(httpx.AsyncClient):
         return False
 
     async def Delete_Lock(self) -> bool:
-        if self.protected:
+        if await self.protected():
             raise InvalidPIN()
         return await self.Lock_Inbox('', 0)
 
